# EzDocxTemplate
Library that extends the functionality of python-docx
like https://github.com/elapouya/python-docx-template but mine (and worse)


## new functionality
- Replacement of a placeholder with:
    - Plain text
    - A group of elements (even from another document)
- Table population


## TODO
- make image copying work
- Adding elements from HTML (convert to DOCX first and then load)
- Populating smart tables:
    - Only one/some columns
    - Filling existing cells